==> foundation-ui-components-1.1.0.tgz: package/src/common/auth-dropdown/NsAuthDropdown.styled.ts <==
import { styled, ColorUtils } from '@nuskin/foundation-theme';

const { color, paletteColor } = ColorUtils;

export const AuthDropdownContainer = styled.div`
    position: relative;
    display: inline-block;
`;

export const AuthDropdown = styled.div`
    min-width: 280px;
    background-color: white;
    color: black;
    text-align: center;
    padding: 5px 0;
    position: absolute;
    z-index: 600;
    top: calc(100% + 18px);
    right: 5%;
    box-shadow: 0 0 5px 0 ${color('neutral', '20')};
    transition: all 0.15s ease-in-out;
    padding: 25px;
`;

export const Triangle = styled.div`
    position: absolute;
    bottom: -18px;
    left: 50%;
    width: 24px;
    height: 24px;
    overflow: hidden;
    transition: all 0.15s ease-in-out;
    z-index: 700;
    opacity: 1;
    &::after {
        content: '';
        position: absolute;
        width: 14px;
        height: 14px;
        background-color: ${color('primary', 'white')};
        transform: rotate(45deg);
        top: 17px;
        left: 5px;
        box-shadow: 0 0 5px 0 ${color('neutral', '20')};
    }
`;

export const AuthHead = styled.div<{ darkModeEnabled: boolean }>`
    cursor: pointer;
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    color: ${paletteColor('primary')};
`;

export const Button = styled.div`
    padding-right: 10px;
`;

export const Link = styled.a`
    text-decoration: none;
`;

export const SignInButton = styled(Link)`
    display: block;
    padding: 13px;
    width: 100%;
    background-color: ${color('primary', 'black')};
    color: ${color('primary', 'white')};
    border: 0;
    font-size: 16px;
    &:hover {
        background-color: ${color('neutral', '70')};
    }
`;

export const SignUpLinkContainer = styled.div`
    margin-top: 15px;
    color: ${color('primary', 'black')};
    font-size: 13px;
    line-height: 16px;
    text-align: left;
`;

export const SignUpLink = styled(Link)`
    cursor: pointer;
    font-weight: 300;
    font-size: 13px;
    line-height: 16px;
    text-decoration: none;
    color: ${color('primary', 'black')};
    position: relative;
    transition: all 0.15s ease-in-out;
    &:hover {
        color: ${color('neutral', '70')};
        font-size: 14px;
    }
    &:hover::after {
        opacity: 1;
        visibility: visible;
    }
    &::after {
        content: '';
        position: absolute;
        bottom: -2px;
        left: 0;
        right: 0;
        width: 100%;
        height: 1px;
        background-color: ${color('primary', 'black')};
        transition: all 0.15s ease-in-out;
        opacity: 0;
        visibility: hidden;
    }
`;

==> foundation-ui-components-1.15.0.tgz: package/src/common/auth-dropdown/NsAuthDropdown.styled.ts <==
import { styled, ColorUtils } from '@nuskin/foundation-theme';
import { DarkModeEnabledOption } from '../common.types';

//[TODO-Arun] - Use from custom color variables
// const MAGENTA_COLOR = '#bb29bb';

const { color, paletteColor } = ColorUtils;

export const AuthDropdownContainer = styled.div`
    position: relative;
    display: inline-block;
`;

export const AuthDropdown = styled.div`
    min-width: 280px;
    background-color: white;
    color: black;
    text-align: center;
    padding: 5px 0;
    position: absolute;
    z-index: 600;
    top: calc(100% + 18px);
    right: 5%;
    box-shadow: 0 0 5px 0 ${color('neutral', '20')};
    transition: all 0.15s ease-in-out;
    padding: 25px;
`;

export const Triangle = styled.div`
    position: absolute;
    bottom: -18px;
    left: 50%;
    width: 24px;
    height: 24px;
    overflow: hidden;
    transition: all 0.15s ease-in-out;
    z-index: 700;
    opacity: 1;
    &::after {
        content: '';
        position: absolute;
        width: 14px;
        height: 14px;
        background-color: ${color('primary', 'white')};
        transform: rotate(45deg);
        top: 17px;
        left: 5px;
        box-shadow: 0 0 5px 0 ${color('neutral', '20')};
    }
`;
export const AuthHead = styled('div')<DarkModeEnabledOption>`
    cursor: pointer;
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    color: ${paletteColor('primary')};
`;

export const Button = styled.div`
    padding-right: 10px;
`;

export const Link = styled.a`
    text-decoration: none;
`;

export const SignInButton = styled(Link)`
    display: block;
    padding: 13px;
    width: 100%;
    background-color: ${color('primary', 'black')};
    color: ${color('primary', 'white')};
    border: 0;
    font-size: 16px;
    &:hover {
        background-color: ${color('neutral', '70')};
    }
`;

export const SignUpLinkContainer = styled.div`
    margin-top: 15px;
    color: ${color('primary', 'black')};
    font-size: 13px;
    line-height: 16px;
    text-align: left;
`;

export const SignUpLink = styled(Link)`
    cursor: pointer;
    font-weight: 300;
    font-size: 13px;
    line-height: 16px;
    text-decoration: none;
    color: ${color('primary', 'black')};
    position: relative;
    transition: all 0.15s ease-in-out;
    &:hover {
        color: ${color('neutral', '70')};
        font-size: 14px;
    }
    &:hover::after {
        opacity: 1;
        visibility: visible;
    }
    &::after {
        content: '';
        position: absolute;
        bottom: -2px;
        left: 0;
        right: 0;
        width: 100%;
        height: 1px;
        background-color: ${color('primary', 'black')};
        transition: all 0.15s ease-in-out;
        opacity: 0;
        visibility: hidden;
    }
`;
